<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


// in src/Form/NetworkBasicForm.php
namespace NWCModule\Form;

use App\Form\WizardSNMPForm;
use Cake\Validation\Validator;

/**
 * Class NetworkBasicForm
 * @package NWCModule\Form
 */
class NetworkBasicForm extends WizardSNMPForm {
    public function validationDefault(Validator $validator): Validator {
        $validator
            ->requirePresence('snmpCommunity')
            ->allowEmptyString('snmpCommunity', null, function ($context) {
                return isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3';
            });
        $validator
            ->requirePresence('securityName')
            ->allowEmptyString('securityName', null, function ($context) {
                if (isset($context['data']['snmpVersion']) &&
                    in_array($context['data']['snmpVersion'], ['1', '2'], true)) {
                    return true;
                }
                return !(isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3' &&
                    $context['data']['securityLevel'] !== '3');
            });
        $validator
            ->requirePresence('authPassword')
            ->allowEmptyString('authPassword', null, function ($context) {
                return !(isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3' &&
                    $context['data']['securityLevel'] !== '3');
            });
        $validator
            ->requirePresence('privacyProtocol')
            ->allowEmptyString('privacyProtocol', null, function ($context) {
                return !(isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3' &&
                    $context['data']['securityLevel'] !== '3');
            });
        $validator
            ->requirePresence('authProtocol')
            ->allowEmptyString('authProtocol', null, function ($context) {
                return !(isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3' &&
                    $context['data']['securityLevel'] !== '3');
            });
        $validator
            ->requirePresence('privacyPassword')
            ->allowEmptyString('privacyPassword', null, function ($context) {
                return !(isset($context['data']['snmpVersion']) && $context['data']['snmpVersion'] === '3' &&
                    $context['data']['securityLevel'] !== '3');
            });

        $validator
            ->allowEmptyArray('services', __('Please select at least one service or interface'), function ($context) {
                if (sizeof($context['data']['interfaces']) > 0) {
                    return true;
                }
                return false;
            });

        $validator
            ->allowEmptyArray('interfaces', __('Please select at least one service or interface'), function ($context) {
                if (sizeof($context['data']['services']) > 0) {
                    return true;
                }
                return false;
            });

        return $validator;
    }
}
