<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.

namespace NWCModule\Lib\InitialDatabase;

use App\Model\Table\CommandsTable;
use App\Model\Table\ServicetemplategroupsTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package NWCModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {

    /**
     * @var CommandsTable
     */
    private $CommandsTable;

    /**
     * @var ServicetemplatesTable
     */
    private $ServicetemplatesTable;

    /**
     * @var ServicetemplategroupsTable
     */
    private $ServicetemplategroupsTable;

    /**
     * @var WizardAssignmentsTable
     */
    private $WizardAssignmentsTable;

    /**
     * @var array
     */
    private $mapping = [];

    /**
     * TemplateImport constructor.
     * @param CommandsTable $CommandsTable
     * @param ServicetemplatesTable $ServicetemplatesTable
     * @param ServicetemplategroupsTable $ServicetemplategroupsTable
     * @param WizardAssignmentsTable $WizardAssignmentsTable
     */
    public function __construct(CommandsTable $CommandsTable, ServicetemplatesTable $ServicetemplatesTable, ServicetemplategroupsTable $ServicetemplategroupsTable, WizardAssignmentsTable $WizardAssignmentsTable) {
        $this->CommandsTable = $CommandsTable;
        $this->ServicetemplatesTable = $ServicetemplatesTable;
        $this->ServicetemplategroupsTable = $ServicetemplategroupsTable;
        $this->WizardAssignmentsTable = $WizardAssignmentsTable;
    }

    /**
     * @return bool
     */
    public function import() {
        $data = $this->getData();
        foreach ($data['Commands'] as $command) {
            if (isset($command['uuid']) && !$this->CommandsTable->existsByUuid($command['uuid'])) {
                $entity = $this->CommandsTable->newEntity($command);
                $this->CommandsTable->save($entity);
            }
        }
        $this->mapping['servicetemplates'] = [];

        foreach ($data['Servicetemplates'] as $servicetemplate) {
            if ($this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                $existingServicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplate['uuid']);
                $this->mapping['servicetemplates'][$servicetemplate['uuid']] = $existingServicetemplate['Servicetemplate']['id'];
                //skip current template if it already exists
                continue;
            }
            if (isset($servicetemplate['uuid']) && !$this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                if (isset($servicetemplate['command_id']) && $this->CommandsTable->existsByUuid($servicetemplate['command_id'])) {
                    $command = $this->CommandsTable->getCommandByUuid($servicetemplate['command_id'], true, false)[0];
                    $servicetemplate['command_id'] = $command['id'];
                    if (!empty($servicetemplate['servicetemplatecommandargumentvalues']) && !empty($command['commandarguments'])) {
                        foreach ($servicetemplate['servicetemplatecommandargumentvalues'] as $templateArgumentKey => $templateArgumentValue) {
                            $servicetemplate['servicetemplatecommandargumentvalues'][$templateArgumentKey] = [
                                'commandargument_id' => $this->getCommandArgumentIdByName($templateArgumentValue['commandargument_id'], $command['commandarguments']),
                                'value'              => $templateArgumentValue['value'],
                            ];
                        }
                    }
                    $entity = $this->ServicetemplatesTable->newEntity($servicetemplate);
                    $this->ServicetemplatesTable->save($entity);
                    $this->mapping['servicetemplates'][$entity->get('uuid')] = $entity->get('id');
                }
            }
        }

        foreach ($data['Servicetemplategroups'] as $servicetemplategroup) {
            if ($this->ServicetemplategroupsTable->existsByUuid($servicetemplategroup['uuid'])) {
                //skip current template if its already exists
                continue;
            }

            if (!empty($this->mapping['servicetemplates'])) {
                foreach ($servicetemplategroup['servicetemplates'] as $key => $servicetemplate) {
                    $currIdAsUuid = $servicetemplate['id'];
                    if (isset($this->mapping['servicetemplates'][$currIdAsUuid])) {
                        $servicetemplategroup['servicetemplates']['_ids'][] = $this->mapping['servicetemplates'][$currIdAsUuid];
                    }

                }
            }

            $entity = $this->ServicetemplategroupsTable->newEntity($servicetemplategroup);
            $this->ServicetemplategroupsTable->save($entity);
        }


        if (!empty($data['Wizardassignment'])) {
            $wizardassignmentEntity['uuid'] = $data['Wizardassignment']['uuid'];
            $wizardassignmentEntity['type_id'] = $data['Wizardassignment']['type_id'];
            foreach ($data['Wizardassignment']['servicetemplates']['_ids'] as $servicetemplateUuid) {
                $servicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplateUuid);
                if (isset($servicetemplate['Servicetemplate']) && isset($servicetemplate['Servicetemplate']['id'])) {
                    $wizardassignmentEntity['servicetemplates']['_ids'][] = $servicetemplate['Servicetemplate']['id'];
                }
            }
            if (!$this->WizardAssignmentsTable->existsByUuidAndTypeId($wizardassignmentEntity['uuid'], $wizardassignmentEntity['type_id'])) {
                $entity = $this->WizardAssignmentsTable->newEntity($wizardassignmentEntity);
                $this->WizardAssignmentsTable->save($entity);
            } else {
                $existingAssignment = $this->WizardAssignmentsTable->getWizardByUuidForEdit($wizardassignmentEntity['uuid']);
                foreach (array_diff($wizardassignmentEntity['servicetemplates']['_ids'], $existingAssignment['servicetemplates']['_ids']) as $missingServicetemplateId) {
                    $existingAssignment['servicetemplates']['_ids'][] = $missingServicetemplateId;
                }
                $entity = $this->WizardAssignmentsTable->get($existingAssignment['id']);
                $entity = $this->WizardAssignmentsTable->patchEntity($entity, $existingAssignment);
                $this->WizardAssignmentsTable->save($entity);
            }
        }


        return true;
    }

    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData(),
            'Wizardassignment'      => $this->getWizardAssignmentData()
        ];
    }

    /**
     * @param string $name
     * @param array $commandarguments
     * @return bool|mixed
     */
    public function getCommandArgumentIdByName(string $name, array $commandarguments) {
        foreach ($commandarguments as $commandargument) {
            if (isset($commandargument['name']) && $commandargument['name'] === $name) {
                return $commandargument['id'];
            }
        }
        return false;
    }

    /**
     * @return array
     */
    public function getWizardAssignmentData() {
        $data = [
            'uuid'             => 'cf3abeba-80f8-4307-8b86-c198cc9c576e',
            'type_id'          => 'network',
            'servicetemplates' => [
                '_ids' => [
                    'dd9cdbfa-0639-4616-8ee6-01ae11f2b70e',
                    'fcea809f-b405-4f43-8a3b-144fadbbce4d',
                    '9188bdf8-ec32-4328-be45-f17ec4cacd88',
                    '6495bb89-f87f-4093-b91c-bc2ab3b47ca9',
                    'eef5b2c4-d807-4b34-81cc-ddd63b950114',
                    'b42d538a-dbbd-4db4-8f1a-7fefb85da6bf',
                    '3ae2bf3a-0ac9-4c1a-abec-253af742390e',
                    'f08d15ab-4de9-4a2d-8d3c-3f5bf13c21e7',
                    'de5e3045-3011-45d8-8ac6-bc5fbb3d396d'
                ]
            ]
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        //$_HOSTSNMP_SETTINGS$ : --protocol 3 --username snmpv3username --authpassword snmpv3passwort --authprotocol sha --privprotocol aes --privpassword snmpv3passwort
        $data = [
            // Hardware Health
            0 => [
                'name'             => 'check_nwc_health_hardware_health',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode hardware-health --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '191d5d7e-925c-4e5f-bfd3-e5d29b79d5de',
                'description'      => 'Check the status of environmental equipment (fans, temperatures, power)',
                'commandarguments' => []
            ],
            //CPU Load
            1 => [
                'name'             => 'check_nwc_health_cpu_load',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode cpu-load --warning $ARG1$ --critical $ARG2$ --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '94d32079-2f0f-4c82-b589-18756ea77ab3',
                'description'      => 'Check the CPU load of the device',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Warning',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Critical',
                    ],
                ]
            ],
            //Memory Usage
            2 => [
                'name'             => 'check_nwc_health_memory_usage',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode memory-usage --warning $ARG1$ --critical $ARG2$ --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'a0b56e5c-9f6b-44ea-b0ea-4bd0256759a8',
                'description'      => 'Check the memory usage of the device',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Warning',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Critical',
                    ],
                ]
            ],
            //Disk Usage
            3 => [
                'name'             => 'check_nwc_health_disk_usage',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode disk-usage --warning $ARG1$ --critical $ARG2$ --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '4b6b3333-0deb-49e7-a5ad-bae514a72b7e',
                'description'      => 'Check the disk usage of the device',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Warning',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Critical',
                    ],
                ]
            ],
            //HA Status
            4 => [
                'name'             => 'check_nwc_health_ha_status',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode ha-status --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'f5c424e9-5d28-40bf-988f-194a0e1dd4cf',
                'description'      => 'Check the status of a clustered setup',
                'commandarguments' => []
            ],
            //HA Role
            5 => [
                'name'             => 'check_nwc_health_ha_role',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode ha-role --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '38fc1660-acb8-4b76-9593-fbf47d3b5bbf',
                'description'      => 'Check the role in a ha group',
                'commandarguments' => []
            ],
            //Session Usage
            6 => [
                'name'             => 'check_nwc_health_session_usage',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode session-usage --warning $ARG1$ --critical $ARG2$ --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '2fb82f10-7cdc-49ac-a16a-4b1cc2abb0ae',
                'description'      => 'Check the session limits of a load balancer',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Warning',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Critical',
                    ],
                ]
            ],
            //List of interfaces
            7 => [
                'name'             => 'check_nwc_health_list_interfaces',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode list-interfaces --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '4dfd17bb-de82-4777-bb1f-a3c96527f59b',
                'description'      => 'Show the interfaces of the device and update the name cache',
                'commandarguments' => []
            ],
            //Health of interfaces by name as parameter
            8 => [
                'name'             => 'check_nwc_interface_health',
                'command_line'     => '$USER1$/check_nwc_health --hostname $HOSTADDRESS$ $_HOSTSNMP_SETTINGS$ --mode interface-health --name "$ARG1$" --warningx ".*usage.*"=$ARG2$ --criticalx ".*usage.*"=$ARG3$ --statefilesdir /var/tmp/check_nwc_health',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'fda5997f-c438-406e-980c-f76f5bfa0346',
                'description'      => 'Check everything interface',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Interface name',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Warning',
                    ],
                    2 => [
                        'name'       => '$ARG3$',
                        'human_name' => 'Critical',
                    ],
                ],
            ],
        ];
        return $data;
    }


    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0 => [
                'uuid'                                      => 'dd9cdbfa-0639-4616-8ee6-01ae11f2b70e',
                'template_name'                             => 'NETWORK_NWC_HARDWARE_HEALTH',
                'name'                                      => 'Hardware Health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the status of environmental equipment',
                'command_id'                                => '191d5d7e-925c-4e5f-bfd3-e5d29b79d5de',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            1 => [
                'uuid'                                      => 'fcea809f-b405-4f43-8a3b-144fadbbce4d',
                'template_name'                             => 'NETWORK_NWC_CPU_LOAD',
                'name'                                      => 'CPU Load',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the CPU load of the device',
                'command_id'                                => '94d32079-2f0f-4c82-b589-18756ea77ab3',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '80',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => '90',
                    ]
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            2 => [
                'uuid'                                      => '9188bdf8-ec32-4328-be45-f17ec4cacd88',
                'template_name'                             => 'NETWORK_NWC_MEMORY_USAGE',
                'name'                                      => 'Memory usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the memory usage of the device',
                'command_id'                                => 'a0b56e5c-9f6b-44ea-b0ea-4bd0256759a8',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '80',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => '90',
                    ]
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            3 => [
                'uuid'                                      => '6495bb89-f87f-4093-b91c-bc2ab3b47ca9',
                'template_name'                             => 'NETWORK_NWC_DISK_USAGE',
                'name'                                      => 'Disk usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the disk usage of the device',
                'command_id'                                => '4b6b3333-0deb-49e7-a5ad-bae514a72b7e',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '80',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => '90',
                    ]
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            4 => [
                'uuid'                                      => 'eef5b2c4-d807-4b34-81cc-ddd63b950114',
                'template_name'                             => 'NETWORK_NWC_HA_STATUS',
                'name'                                      => 'HA Status',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the status of a clustered setup',
                'command_id'                                => 'f5c424e9-5d28-40bf-988f-194a0e1dd4cf',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            5 => [
                'uuid'                                      => 'b42d538a-dbbd-4db4-8f1a-7fefb85da6bf',
                'template_name'                             => 'NETWORK_NWC_HA_ROLE',
                'name'                                      => 'HA Role',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the role in a ha group',
                'command_id'                                => '38fc1660-acb8-4b76-9593-fbf47d3b5bbf',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            6 => [
                'uuid'                                      => '3ae2bf3a-0ac9-4c1a-abec-253af742390e',
                'template_name'                             => 'NETWORK_NWC_SESSION_USAGE',
                'name'                                      => 'Session usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check the session limits of a load balancer',
                'command_id'                                => '2fb82f10-7cdc-49ac-a16a-4b1cc2abb0ae',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '1000',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => '1500',
                    ]
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            7 => [
                'uuid'                                      => 'f08d15ab-4de9-4a2d-8d3c-3f5bf13c21e7',
                'template_name'                             => 'NETWORK_NWC_LIST_INTERFACES',
                'name'                                      => 'List interfaces',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Show the interfaces of the device and update the name cache',
                'command_id'                                => '4dfd17bb-de82-4777-bb1f-a3c96527f59b',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            8 => [
                'uuid'                                      => 'de5e3045-3011-45d8-8ac6-bc5fbb3d396d',
                'template_name'                             => 'NETWORK_NWC_INTERFACE_HEALTH',
                'name'                                      => 'Interface health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Check everything interface',
                'command_id'                                => 'fda5997f-c438-406e-980c-f76f5bfa0346',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '0',
                'notify_on_warning'                         => '0',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => null,
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2020-09-28 11:31:14',
                'modified'                                  => '2020-09-28 11:31:14',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'lo',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => '80',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '90',
                    ]
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ]
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 => [
                'uuid'             => 'b6218058-c688-4e37-b322-cc8ce4423aff',
                'description'      => 'Network Basic Monitoring over SNMP without Interfaces',
                'servicetemplates' => [
                    0 => [
                        'id'   => 'dd9cdbfa-0639-4616-8ee6-01ae11f2b70e',
                        'uuid' => 'dd9cdbfa-0639-4616-8ee6-01ae11f2b70e',
                    ],
                    1 => [
                        'id'   => 'fcea809f-b405-4f43-8a3b-144fadbbce4d',
                        'uuid' => 'fcea809f-b405-4f43-8a3b-144fadbbce4d',
                    ],
                    2 => [
                        'id'   => '9188bdf8-ec32-4328-be45-f17ec4cacd88',
                        'uuid' => '9188bdf8-ec32-4328-be45-f17ec4cacd88',
                    ],
                    3 => [
                        'id'   => '6495bb89-f87f-4093-b91c-bc2ab3b47ca9',
                        'uuid' => '6495bb89-f87f-4093-b91c-bc2ab3b47ca9',
                    ],
                    4 => [
                        'id'   => 'eef5b2c4-d807-4b34-81cc-ddd63b950114',
                        'uuid' => 'eef5b2c4-d807-4b34-81cc-ddd63b950114',
                    ],
                    5 => [
                        'id'   => 'b42d538a-dbbd-4db4-8f1a-7fefb85da6bf',
                        'uuid' => 'b42d538a-dbbd-4db4-8f1a-7fefb85da6bf',
                    ],
                    6 => [
                        'id'   => '3ae2bf3a-0ac9-4c1a-abec-253af742390e',
                        'uuid' => '3ae2bf3a-0ac9-4c1a-abec-253af742390e',
                    ]
                ],
                'container'        => [
                    'name'             => 'Network Basic Monitoring',
                    'parent_id'        => 1,
                    'containertype_id' => '9',
                ],
            ]
        ];
        return $data;
    }
}
